package com.ruoyi.tuya.service;

import java.util.List;
import com.ruoyi.tuya.domain.TuyaTalkNo;

/**
 * 用户投诉Service接口
 * 
 * @author zf
 * @date 2022-08-23
 */
public interface ITuyaTalkNoService 
{
    /**
     * 查询用户投诉
     * 
     * @param noId 用户投诉主键
     * @return 用户投诉
     */
    public TuyaTalkNo selectTuyaTalkNoByNoId(Long noId);

    /**
     * 查询用户投诉列表
     * 
     * @param tuyaTalkNo 用户投诉
     * @return 用户投诉集合
     */
    public List<TuyaTalkNo> selectTuyaTalkNoList(TuyaTalkNo tuyaTalkNo);

    /**
     * 新增用户投诉
     * 
     * @param tuyaTalkNo 用户投诉
     * @return 结果
     */
    public int insertTuyaTalkNo(TuyaTalkNo tuyaTalkNo);

    /**
     * 修改用户投诉
     * 
     * @param tuyaTalkNo 用户投诉
     * @return 结果
     */
    public int updateTuyaTalkNo(TuyaTalkNo tuyaTalkNo);

    /**
     * 批量删除用户投诉
     * 
     * @param noIds 需要删除的用户投诉主键集合
     * @return 结果
     */
    public int deleteTuyaTalkNoByNoIds(Long[] noIds);

    /**
     * 删除用户投诉信息
     * 
     * @param noId 用户投诉主键
     * @return 结果
     */
    public int deleteTuyaTalkNoByNoId(Long noId);
}
